check_ddl_changes

Function check_ddl_changes 

async fn check_ddl_changes(
    boot_ts: Timestamp,
    persist_client: PersistClient,
    environment_id: EnvironmentId,
    deploy_generation: u64,
    catalog_metrics: Arc<Metrics>,
    bootstrap_args: BootstrapArgs,
    initial_next_user_item_id: u64,
    initial_next_replica_id: u64,
)
Check if there have been any DDL that create new collections or replicas, restart in read-only mode if so, in order to pick up those new items and start hydrating them before cutting over.

We do this by checking whether items or replicas with IDs above the highest ones in the catalog snapshot this deployment bootstrapped from were committed.