get_next_ids

Function get_next_ids 

async fn get_next_ids(
    boot_ts: Timestamp,
    persist_client: PersistClient,
    environment_id: EnvironmentId,
    deploy_generation: u64,
    catalog_metrics: Arc<Metrics>,
    bootstrap_args: BootstrapArgs,
) -> (u64, u64)
Gets and returns the next user item ID and user replica ID based on the maximum existing IDs in the catalog.

We compute these from the actual catalog items rather than the allocator counter (e.g. get_next_user_item_id()), because batch ID allocation (IdPool) can advance the counter far ahead of actually-created items. Using the counter would cause check_ddl_changes to miss items created from the pool, since their IDs would be below the counter value.